@@ -105,7 +105,7 @@ reactionType <- function(reactionList) {
     })
   # Define type of reaction
   sapply(seq_along(reactionList), function(reaction) {
-    if (all(is.na(left[[reaction]])) && all(is.na(right[[reaction]]))) {
+    if ((all(is.na(left[[reaction]])) && all(is.na(right[[reaction]])))) {
       return("No compartmentalized reaction")
     } else if (all(is.na(right[[reaction]]))) {
       return("Exchange reaction")
@@ -280,7 +280,7 @@ rearmReactions <-
 convertData <- function(model) {
   data <- NULL
   data$ID <- model@react_id
-  data$DESCRIPTION <- rep(x = "", model@react_num)
+  data$DESCRIPTION <- model@react_name
   S <- as.matrix(model@S)
   rownames(S) <- model@met_id
   data$REACTION <-
